@@ -16,20 +16,24 @@
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
-*  Copyright: 2002-2014 by Henrik Just
+*  Copyright: 2002-2015 by Henrik Just
 *
 *  All Rights Reserved.
 * 
-*  Version 1.4 (2014-09-23)
+*  Version 1.6 (2015-06-16)
 *
 */ 
 
 package org.openoffice.da.comp.writer2xhtml;
 
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
 import java.util.Map;
 
 import org.openoffice.da.comp.w2lcommon.filter.ConfigurationDialogBase;
 import org.openoffice.da.comp.w2lcommon.helper.DialogAccess;
+import writer2latex.api.Converter;
+import writer2latex.api.ConverterFactory;
 
 import com.sun.star.container.NoSuchElementException;
 import com.sun.star.lang.XServiceInfo;
@@ -95,7 +99,7 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     // Implement remaining method from XContainerWindowEventHandler
     public String[] getSupportedMethodNames() {
     	String[] sNames = { "EncodingChange", // General
-    			"CustomTemplateChange", "LoadTemplateClick", // Template
+    			"CustomTemplateChange", "LoadTemplateClick", "TemplateKeyup", // Template
     			"UseCustomStylesheetChange", "IncludeCustomStylesheetClick", "LoadStylesheetClick",
     			"NewResourceClick", "DeleteResourceClick", // Stylesheet
     			"StyleFamilyChange", "StyleNameChange", "NewStyleClick", "DeleteStyleClick", "LoadDefaultsClick" // Styles1
@@ -170,6 +174,7 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     	}
     	
     	protected void useCustomInner(DialogAccess dlg, boolean bEnable) {
+    		dlg.setControlEnabled("TestTemplateLabel", bEnable);
     		dlg.setControlEnabled("ContentIdLabel", bEnable);
     		dlg.setControlEnabled("ContentId", bEnable);
     		dlg.setControlEnabled("HeaderIdLabel", bEnable);
@@ -187,6 +192,7 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     		if (sCustomIds.length>1) { dlg.setComboBoxText("HeaderId", sCustomIds[1]); }
     		if (sCustomIds.length>2) { dlg.setComboBoxText("FooterId", sCustomIds[2]); }
     		if (sCustomIds.length>3) { dlg.setComboBoxText("PanelId", sCustomIds[3]); }
+    		testTemplate(dlg);
     	}
 
     	@Override protected void getControls(DialogAccess dlg) {
@@ -198,6 +204,38 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     				dlg.getComboBoxText("PanelId").trim());
     	}
     	
+    	@Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
+    		if (super.handleEvent(dlg, sMethod)) {
+    			return true;
+    		}
+    		if (sMethod.equals("TemplateKeyup")) {
+    			testTemplate(dlg);
+    			return true;
+    		}
+    		return false;
+    	}
+    	
+		@Override protected void loadCustomClick(DialogAccess dlg) {
+			super.loadCustomClick(dlg);
+			testTemplate(dlg);
+		}
+    	
+    	private void testTemplate(DialogAccess dlg) {
+    		Converter converter = ConverterFactory.createConverter("text/html");
+    		String sTemplate = dlg.getTextFieldText("CustomTemplate").trim();
+    		if (sTemplate.length()>0) { // Only display error message if there is content
+	    		try {
+					converter.readTemplate(new ByteArrayInputStream(sTemplate.getBytes()));
+		    		dlg.setLabelText("TestTemplateLabel", "");
+				} catch (IOException e) {
+		    		dlg.setLabelText("TestTemplateLabel", "ERROR: "+e.getMessage());
+				}
+    		}
+    		else {
+	    		dlg.setLabelText("TestTemplateLabel", "");    			
+    		}
+    	}
+
     }
 
     private class StylesheetsHandler extends CustomFileHandler {
@@ -363,6 +401,18 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
 			if (!attr.containsKey("css")) { attr.put("css", ""); }
 			dlg.setComboBoxText("Element", attr.get("element"));
 			dlg.setTextFieldText("Css", none2empty(attr.get("css")));
+			
+			if (nCurrentFamily==1 || nCurrentFamily==2) {
+				if (!attr.containsKey("before")) { attr.put("before", ""); }
+				if (!attr.containsKey("after")) { attr.put("after", ""); }
+				dlg.setTextFieldText("Before", attr.get("before"));
+				dlg.setTextFieldText("After", attr.get("after"));
+			}
+			else {
+				dlg.setTextFieldText("Before", "");
+				dlg.setTextFieldText("After", "");				
+			}
+			
 			if (nCurrentFamily==1 || nCurrentFamily==2) {
 				if (!attr.containsKey("block-element")) { attr.put("block-element", ""); }
 				if (!attr.containsKey("block-css")) { attr.put("block-css", ""); }
@@ -378,6 +428,10 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
 		protected void getControls(DialogAccess dlg, Map<String,String> attr) {
 			attr.put("element", dlg.getComboBoxText("Element"));
 			attr.put("css", empty2none(dlg.getTextFieldText("Css")));
+			if (nCurrentFamily==1 || nCurrentFamily==2) {
+				attr.put("before", dlg.getTextFieldText("Before"));
+				attr.put("after", dlg.getTextFieldText("After"));
+			}
 			if (nCurrentFamily==1 || nCurrentFamily==2) {
 				attr.put("block-element", dlg.getComboBoxText("BlockElement"));
 				attr.put("block-css", empty2none(dlg.getTextFieldText("BlockCss")));
@@ -387,6 +441,8 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
 		protected void clearControls(DialogAccess dlg) {
 			dlg.setComboBoxText("Element", "");
 			dlg.setTextFieldText("Css", "");
+			dlg.setTextFieldText("Before", "");
+			dlg.setTextFieldText("After", "");
 			dlg.setComboBoxText("BlockElement", "");
 			dlg.setTextFieldText("BlockCss", "");
 		}
@@ -397,7 +453,11 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
 			dlg.setControlEnabled("ElementLabel", bHasMappings && nCurrentFamily<=2);			
 			dlg.setControlEnabled("Element", bHasMappings && nCurrentFamily<=2);			
 			dlg.setControlEnabled("CssLabel", bHasMappings);			
-			dlg.setControlEnabled("Css", bHasMappings);			
+			dlg.setControlEnabled("Css", bHasMappings);
+			dlg.setControlEnabled("BeforeLabel", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
+			dlg.setControlEnabled("Before", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
+			dlg.setControlEnabled("AfterLabel", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
+			dlg.setControlEnabled("After", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
 			dlg.setControlEnabled("BlockElementLabel", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
 			dlg.setControlEnabled("BlockElement", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));
 			dlg.setControlEnabled("BlockCssLabel", bHasMappings && (nCurrentFamily==1 || nCurrentFamily==2));		
@@ -462,9 +522,10 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     		checkBoxFromConfig(dlg, "IgnoreTableDimensions", "ignore_table_dimensions");
     		
     		listBoxFromConfig(dlg, "ListFormatting", "list_formatting", sListExportValues, (short) 0);
-    		//TODO: These have been postponed
-    		//checkBoxFromConfig(dlg, "ConvertToPx", "convert_to_px");
-    		//checkBoxFromConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
+
+    		textFieldFromConfig(dlg, "MaxWidth", "max_width");
+
+    		checkBoxFromConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
     	}
     	
     	@Override protected void getControls(DialogAccess dlg) {
@@ -477,9 +538,10 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     		checkBoxToConfig(dlg, "IgnoreTableDimensions", "ignore_table_dimensions");
 
     		listBoxToConfig(dlg, "ListFormatting", "list_formatting", sListExportValues);
-    		//TODO: These have been postponed
-    		//checkBoxToConfig(dlg, "ConvertToPx", "convert_to_px");
-    		//checkBoxToConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
+
+    		textFieldToConfig(dlg, "MaxWidth", "max_width");
+
+    		checkBoxToConfig(dlg, "SeparateStylesheet", "separate_stylesheet");
     	}
     	
     	@Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
@@ -496,6 +558,7 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     		textFieldFromConfig(dlg, "EndnotesHeading", "endnotes_heading");
     		textFieldFromConfig(dlg, "FootnotesHeading", "footnotes_heading");
     		checkBoxFromConfig(dlg, "EmbedSvg", "embed_svg");
+    		checkBoxFromConfig(dlg, "EmbedImg", "embed_img");
     	}
     	
     	@Override protected void getControls(DialogAccess dlg) {
@@ -503,6 +566,7 @@ public class ConfigurationDialog extends ConfigurationDialogBase implements XSer
     		textFieldToConfig(dlg, "EndnotesHeading", "endnotes_heading");
     		textFieldToConfig(dlg, "FootnotesHeading", "footnotes_heading");
     		checkBoxToConfig(dlg, "EmbedSvg", "embed_svg");
+    		checkBoxToConfig(dlg, "EmbedImg", "embed_img");
     	}
     	
     	@Override protected boolean handleEvent(DialogAccess dlg, String sMethod) {
