@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2010 by Henrik Just
+ *  Copyright: 2002-2015 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.2 (2010-11-28)
+ *  Version 1.6 (2015-06-30)
  *
  */
 
@@ -77,7 +77,7 @@ public class CharStyleConverter extends StyleConverter {
             pack.append("\\usepackage[normalem]{ulem}").nl();
         }
         if (bNeedSubscript && !config.getTextAttributeStyleMap().contains("subscript")) {
-            decl.append("\\newcommand\\textsubscript[1]{\\ensuremath{{}_{\\text{#1}}}}").nl();
+            decl.append("\\providecommand\\textsubscript[1]{\\ensuremath{{}_{\\text{#1}}}}").nl();
         }
         if (!styleNames.isEmpty()) {
             decl.append("% Text styles").nl().append(declarations);
@@ -470,7 +470,7 @@ public class CharStyleConverter extends StyleConverter {
     
     private static final String nfssSize(String sFontSize){
         if (sFontSize==null) return null;
-        return "\\fontsize{"+sFontSize+"}{"+Misc.multiply("120%",sFontSize)+"}\\selectfont";
+        return "\\fontsize{"+sFontSize+"}{"+Calc.multiply("120%",sFontSize)+"}\\selectfont";
     }
     
     // other character formatting
