@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2008 by Henrik Just
+ *  Copyright: 2002-2016 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.0 (2008-09-08)
+ *  Version 1.6 (2015-06-20)
  *
  */
 
@@ -31,19 +31,18 @@ import writer2latex.office.OfficeReader;
 /**
  *  <p>This is an abstract superclass for converter helpers.</p>
  */
-public abstract class ConverterHelper {
+abstract class ConverterHelper {
     
-    protected OfficeReader ofr;
-    protected LaTeXConfig config;
-    protected ConverterPalette palette;
+    OfficeReader ofr;
+    LaTeXConfig config;
+    ConverterPalette palette;
 	
-    protected ConverterHelper(OfficeReader ofr, LaTeXConfig config, ConverterPalette palette) {
+    ConverterHelper(OfficeReader ofr, LaTeXConfig config, ConverterPalette palette) {
         this.ofr = ofr;
         this.config = config;
         this.palette = palette;
     }
 	
-    public void appendDeclarations(LaTeXDocumentPortion pack, LaTeXDocumentPortion decl) {
-    }
+    abstract void appendDeclarations(LaTeXDocumentPortion pack, LaTeXDocumentPortion decl);
     
 }
\ No newline at end of file
