@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2015 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-15)
+ *  Version 1.6 (2015-04-14)
  *
  */
 
@@ -37,6 +37,7 @@ import writer2latex.office.ListStyle;
 import writer2latex.office.OfficeReader;
 import writer2latex.office.StyleWithProperties;
 import writer2latex.office.XMLString;
+import writer2latex.util.Calc;
 import writer2latex.util.Misc;
 
 /* This class converts OpenDocument headings (<code>text:h</code>) and
@@ -246,12 +247,12 @@ public class HeadingConverter extends ConverterHelper {
                         // Note: Use first line as left indent (cannot have separate first line indent)
                         ldp.append("\\renewcommand\\").append(sSecName)
                            .append("{\\@startsection{").append(sSecName).append("}{"+hm.getLevel(i))
-                           .append("}{"+Misc.add(sMarginLeft,sTextIndent)+"}{");
+                           .append("}{"+Calc.add(sMarginLeft,sTextIndent)+"}{");
                         // Suppress indentation after heading? currently not..
                         // ldp.append("-"); 
                         ldp.append(sMarginTop)
                            .append("}{")
-                           .append(Misc.isZero(sMarginBottom) ? "0.1mm" : sMarginBottom)
+                           .append(Calc.isZero(sMarginBottom) ? "0.1mm" : sMarginBottom)
                            .append("}{");
                         // Note: decl.getAfter() may include a page break after, which we ignore
 	                    ldp.append(decl.getBefore());
@@ -277,7 +278,7 @@ public class HeadingConverter extends ConverterHelper {
         ListStyle outline = ofr.getOutlineStyle();
         String[] sNumFormat = new String[6];
         for (int i=nMaxLevel; i>=1; i--) {
-            sNumFormat[i] = ListStyleConverter.numFormat(outline.getLevelProperty(i,
+            sNumFormat[i] = ListConverter.numFormat(outline.getLevelProperty(i,
                                XMLString.STYLE_NUM_FORMAT));
             if (sNumFormat[i]==null || "".equals(sNumFormat[i])) {
                 nSecnumdepth = i-1;
@@ -319,7 +320,7 @@ public class HeadingConverter extends ConverterHelper {
             				if (sTextIndent==null) { sTextIndent = "0cm"; }*/
     						String sTabPos = outline.getLevelStyleProperty(i, XMLString.TEXT_LIST_TAB_STOP_POSITION);
     						if (sTabPos==null) { sTabPos = "0cm"; }
-    						sDistance = Misc.sub(sTabPos, Misc.add(sMarginLeft, sTextIndent));
+    						sDistance = Calc.sub(sTabPos, Calc.add(sMarginLeft, sTextIndent));
     					}
     					else if ("space".equals(sFormat)) {
     						sSpaceChar="\\ ";
