@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2015 by Henrik Just
  *
  *  All Rights Reserved.
  *  
- *  Version 1.4 (2014-09-16)
+ *  Version 1.6 (2015-04-15)
  *  
  */
  
@@ -293,6 +293,9 @@ public class TableFormatter extends ConverterHelper {
         }
 		
     }
+    
+    @Override public void appendDeclarations(LaTeXDocumentPortion pack, LaTeXDocumentPortion decl) {
+	}
 	
     /** is this a longtable? */
     public boolean isLongtable() { return bIsLongtable; }
@@ -378,7 +381,7 @@ public class TableFormatter extends ConverterHelper {
             }
             else if (!bIsTabulary) {
                 // note: The column width in OOo includes padding, which we subtract
-                ba.add("m{"+Misc.add(sColumnWidth[nCol],"-0.2cm")+"}","");
+                ba.add("m{"+Calc.add(sColumnWidth[nCol],"-0.2cm")+"}","");
             }
             else {
                 ba.add("J","");
@@ -447,9 +450,9 @@ public class TableFormatter extends ConverterHelper {
         // calculate column width
         String sTotalColumnWidth = sColumnWidth[nCol];
         for (int i=nCol+1; i<nCol+nColSpan; i++) {
-             sTotalColumnWidth = Misc.add(sTotalColumnWidth,sColumnWidth[i]);
+             sTotalColumnWidth = Calc.add(sTotalColumnWidth,sColumnWidth[i]);
         }
-        sTotalColumnWidth = Misc.add(sTotalColumnWidth,"-0.2cm");
+        sTotalColumnWidth = Calc.add(sTotalColumnWidth,"-0.2cm");
 
         if (bNeedAlign || bNeedLeft || bNeedRight || nColSpan>1) {
             ba.add("\\multicolumn{"+nColSpan+"}{","");
@@ -467,4 +470,5 @@ public class TableFormatter extends ConverterHelper {
         palette.getColorCv().applyBgColor("\\cellcolor",sCellColor[nRow][nCol],ba,context);
 
     }
+
 }
\ No newline at end of file
