@@ -16,32 +16,32 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2015 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-16) 
+ *  Version 1.6 (2015-05-12) 
  * 
  */
 
 package writer2latex.latex.i18n;
 
-import java.io.*;
+import java.io.InputStream;
 import java.util.Hashtable;
 import java.util.Stack;
-//import java.util.Vector;
-//import java.util.Enumeration;
 import java.util.Iterator;
 
 import javax.xml.parsers.SAXParserFactory;
 import javax.xml.parsers.SAXParser;
 
 import writer2latex.util.CSVList;
-import writer2latex.office.*;
 import writer2latex.latex.LaTeXConfig;
 import writer2latex.latex.LaTeXDocumentPortion;
 import writer2latex.latex.ConverterPalette;
 import writer2latex.latex.util.BeforeAfter;
+import writer2latex.office.OfficeReader;
+import writer2latex.office.StyleWithProperties;
+import writer2latex.office.XMLString;
 
 /** This class (and the helpers in the same package) takes care of i18n in
  *  Writer2LaTeX.  In classic LaTeX, i18n is a mixture of inputencodings, fontencodings
@@ -291,21 +291,19 @@ public class ClassicI18n extends I18n {
      *  @param decl other declarations
      */
     public void appendDeclarations(LaTeXDocumentPortion pack, LaTeXDocumentPortion decl) {
-   		pack.append("\\usepackage[")
-   			.append(writeInputenc(config.getInputencoding()))
-            .append("]{inputenc}").nl();
-
-        // usepackage fontenc
-        CSVList fontencs = new CSVList(',');
-        if (bT2A) { fontencs.addValue("T2A"); }
-        if (bGreek) { fontencs.addValue("LGR"); }
-        if (config.useTipa()) { fontencs.addValue("T3"); }
-        fontencs.addValue("T1");
-        pack.append("\\usepackage[").append(fontencs.toString())
-            .append("]{fontenc}").nl();
-
-        // usepackage babel
-		
+    	useInputenc(pack);
+    	useSymbolFonts(pack);
+    	useTextFonts(pack);
+    	useBabel(pack);
+    }
+    
+    private void useInputenc(LaTeXDocumentPortion ldp) {
+    	ldp.append("\\usepackage[")
+			.append(writeInputenc(config.getInputencoding()))
+        .append("]{inputenc}").nl();
+    }
+    
+    private void useBabel(LaTeXDocumentPortion ldp) {
         // If the document contains "anonymous" greek letters we need greek in any case
         // If the document contains "anonymous cyrillic letters we need one of the
         // languages russian, ukrainian or bulgarian
@@ -346,54 +344,123 @@ public class ClassicI18n extends I18n {
         }
 
         if (!babelopt.isEmpty()) {
-            pack.append("\\usepackage[")
-                .append(babelopt.toString())
-                .append("]{babel}").nl();
+            ldp.append("\\usepackage[")
+               .append(babelopt.toString())
+               .append("]{babel}").nl();
             // For Polish we must undefine \lll which is later defined by ams
             if (languages.contains("pl")) { 
-            	pack.append("\\let\\lll\\undefined").nl();
+            	ldp.append("\\let\\lll\\undefined").nl();
             }
-        }
-			
-        // usepackage tipa
-        if (config.useTipa()) {
-            pack.append("\\usepackage[noenc]{tipa}").nl()
-                .append("\\usepackage{tipx}").nl();
-        }
-
-        // usepackage bbding (Has to avoid some nameclashes.)
-        if (config.useBbding()) {
-            pack.append("\\usepackage{bbding}").nl()
-                .append("\\let\\bbCross\\Cross\\let\\Cross\\undefined").nl()
-                .append("\\let\\bbSquare\\Square\\let\\Square\\undefined").nl()
-                .append("\\let\\bbTrianbleUp\\TriangleUp\\let\\TriangleUp\\undefined").nl()
-                .append("\\let\\bbTrianlgeDown\\TriangleDown\\let\\TriangleDown\\undefined").nl();
-        }
-		
-        // usepackage ifsym
-        if (config.useIfsym()) {
-            pack.append("\\usepackage[geometry,weather,misc,clock]{ifsym}").nl();
-        }
-
-        // usepackage pifont
-        if (config.usePifont()) { pack.append("\\usepackage{pifont}").nl(); }
-
-        // usepackage eurosym
-        if (config.useEurosym()) { pack.append("\\usepackage{eurosym}").nl(); }
-
-        // usepackage amsmath (always!)
-        pack.append("\\usepackage{amsmath}").nl();
-
-        // usepackage wasysym (*must* be loaded between amsmath and amsfonts!)
-        if (config.useWasysym()) { 
-            pack.append("\\usepackage{wasysym}").nl();
-        }
-		
-        // usepackage amssymb, amsfonts, textcomp (always!)
-        pack.append("\\usepackage{amssymb,amsfonts,textcomp}").nl();
-		
+        }	
     }
     
+    private void useSymbolFonts(LaTeXDocumentPortion ldp) {
+        if (config.useTipa()) {
+            ldp.append("\\usepackage[noenc]{tipa}").nl()
+               .append("\\usepackage{tipx}").nl();
+        }
+
+        // Has to avoid some nameclashes
+        if (config.useBbding()) {
+            ldp.append("\\usepackage{bbding}").nl()
+               .append("\\let\\bbCross\\Cross\\let\\Cross\\undefined").nl()
+               .append("\\let\\bbSquare\\Square\\let\\Square\\undefined").nl()
+               .append("\\let\\bbTrianbleUp\\TriangleUp\\let\\TriangleUp\\undefined").nl()
+               .append("\\let\\bbTrianlgeDown\\TriangleDown\\let\\TriangleDown\\undefined").nl();
+        }    	
+
+        if (config.useIfsym()) {
+	        ldp.append("\\usepackage[geometry,weather,misc,clock]{ifsym}").nl();
+	    }
+
+        if (config.usePifont()) { ldp.append("\\usepackage{pifont}").nl(); }
+
+        if (config.useEurosym()) { ldp.append("\\usepackage{eurosym}").nl(); }
+
+        // Always use amsmath
+        ldp.append("\\usepackage{amsmath}").nl();
+
+        // wasysym *must* be loaded between amsmath and amsfonts!
+	    if (config.useWasysym()) { 
+	        ldp.append("\\usepackage{wasysym}").nl();
+	    }
+	
+	    // Always use amssymb, amsfonts, textcomp (always!)
+	    ldp.append("\\usepackage{amssymb,amsfonts,textcomp}").nl();
+    }
+    
+    private void useTextFonts(LaTeXDocumentPortion ldp) {
+        // usepackage fontenc
+        CSVList fontencs = new CSVList(',');
+        if (bT2A) { fontencs.addValue("T2A"); }
+        if (bGreek) { fontencs.addValue("LGR"); }
+        if (config.useTipa()) { fontencs.addValue("T3"); }
+        fontencs.addValue("T1");
+        ldp.append("\\usepackage[").append(fontencs.toString())
+            .append("]{fontenc}").nl();
+        
+        // use font package(s)
+        useFontPackages(ldp);		
+    }
+
+    private void useFontPackages(LaTeXDocumentPortion ldp) {
+    	String sFont = config.getFont();
+    	// Sources:
+    	// A Survey of Free Math Fonts for TeX and LaTeX, Stephen G. Hartke 2006
+    	if ("cmbright".equals(sFont)) { // Computer Modern Bright designed by Walter A. Schmidt
+    		ldp.append("\\usepackage{cmbright}").nl();
+    	}
+    	else if ("ccfonts".equals(sFont)) { // Concrete designed by Donald E. Knuth
+    		ldp.append("\\usepackage{ccfonts}").nl();
+    	}
+    	else if ("ccfonts-euler".equals(sFont)) { // Concrete with Euler math fonts
+    		ldp.append("\\usepackage{ccfonts,eulervm}").nl();
+    	}
+    	else if ("iwona".equals(sFont)) { // Iwona
+    		ldp.append("\\usepackage[math]{iwona}").nl();
+    	}
+    	else if ("kurier".equals(sFont)) { // Kurier
+    		ldp.append("\\usepackage[math]{kurier}").nl();
+    	}
+    	else if ("anttor".equals(sFont)) { // Antykwa Torunska 
+    		ldp.append("\\usepackage[math]{anttor}").nl();
+    	}
+    	else if ("kmath-kerkis".equals(sFont)) { // Kerkis
+    		ldp.append("\\usepackage{kmath,kerkis}");
+    	}
+    	else if ("fouriernc".equals(sFont)) { // New Century Schoolbook + Fourier
+    		ldp.append("\\usepackage{fouriernc}");
+    	}
+    	else if ("pxfonts".equals(sFont)) { // Palatino + pxfonts math
+    		ldp.append("\\usepackage{pxfonts}");
+    	}
+    	else if ("mathpazo".equals(sFont)) { // Palatino + Pazo math
+    		ldp.append("\\usepackage{mathpazo}");
+    	}
+    	else if ("mathpple".equals(sFont)) { // Palatino + Euler
+    		ldp.append("\\usepackage{mathpple}");
+    	}
+    	else if ("txfonts".equals(sFont)) { // Times + txfonts math
+    		ldp.append("\\usepackage[varg]{txfonts}");
+    	}
+    	else if ("mathptmx".equals(sFont)) { // Times + Symbol
+    		ldp.append("\\usepackage{mathptmx}");
+    	}
+    	else if ("arev".equals(sFont)) { // Arev Sans + Arev math 
+    		ldp.append("\\usepackage{arev}");
+    	}
+    	else if ("charter-mathdesign".equals(sFont)) { // Bitstream Charter + Math Design
+    		ldp.append("\\usepackage[charter]{mathdesign}");
+    	}
+    	else if ("utopia-mathdesign".equals(sFont)) { // Utopia + Math Design
+    		ldp.append("\\usepackage[utopia]{mathdesign}");
+    	}
+    	else if ("fourier".equals(sFont)) { // Utopia + Fourier
+    		ldp.append("\\usepackage{fourier}");
+    	}
+    }
+
+    
     /** Apply a language language
      *  @param style the OOo style to read attributes from
      *  @param bDecl true if declaration form is required
