@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2011 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.2 (2011-03-08)
+ *  Version 1.6.1 (2018-08-10)
  *
  */
 
@@ -249,6 +249,8 @@ public class XMLString {
 	public static final String TEXT_FOOTNOTES_CONFIGURATION="text:footnotes-configuration";
 	public static final String TEXT_ENDNOTES_CONFIGURATION="text:endnotes-configuration";
 	public static final String TEXT_NOTES_CONFIGURATION="text:notes-configuration"; // oasis
+	public static final String TEXT_BIBLIOGRAPHY_CONFIGURATION="text:bibliography-configuration";
+	public static final String TEXT_SORT_KEY="text:sort-key";
     public static final String TEXT_SECTION_SOURCE="text:section-source";
     public static final String TEXT_SEQUENCE_DECLS="text:sequence-decls";
     public static final String TEXT_SEQUENCE_DECL="text:sequence-decl";
@@ -282,8 +284,14 @@ public class XMLString {
     public static final String TEXT_TABLE_INDEX_SOURCE="text:table-index-source";
     public static final String TEXT_TABLE_INDEX_ENTRY_TEMPLATE="text:table-index-entry-template";
 	public static final String TEXT_OBJECT_INDEX="text:object-index";
-	public static final String TEXT_USER_INDEX="text:user-index";
+	public static final String TEXT_USER_INDEX = "text:user-index";
+	public static final String TEXT_USER_INDEX_SOURCE = "text:user-index-source";
+	public static final String TEXT_USER_INDEX_ENTRY_TEMPLATE = "text:user-index-entry-template";
 	public static final String TEXT_BIBLIOGRAPHY="text:bibliography";
+	public static final String TEXT_BIBLIOGRAPHY_SOURCE="text:bibliography-source";
+    public static final String TEXT_BIBLIOGRAPHY_ENTRY_TEMPLATE="text:bibliography-entry-template";
+    public static final String TEXT_INDEX_ENTRY_BIBLIOGRAPHY="text:index-entry-bibliography";
+    public static final String TEXT_INDEX_ENTRY_SPAN="text:index-entry-span";
     public static final String TEXT_INDEX_TITLE_TEMPLATE="text:index-title-template";
     public static final String TEXT_INDEX_BODY="text:index-body";
     public static final String TEXT_INDEX_TITLE="text:index-title";
@@ -316,6 +324,9 @@ public class XMLString {
     public static final String TEXT_TOC_MARK="text:toc-mark";
     public static final String TEXT_TOC_MARK_START="text:toc-mark-start";
     public static final String TEXT_TOC_MARK_END="text:toc-mark-end";
+	public static final String TEXT_USER_INDEX_MARK = "text:user-index-mark";
+	public static final String TEXT_USER_INDEX_MARK_START = "text:user-index-mark-start";
+	public static final String TEXT_USER_INDEX_MARK_END = "text:user-index-mark-end";
     public static final String TEXT_REFERENCE_MARK="text:reference-mark";
 	public static final String TEXT_REFERENCE_MARK_START="text:reference-mark-start";
 	public static final String TEXT_REFERENCE_MARK_END="text:reference-mark-end";
@@ -338,6 +349,7 @@ public class XMLString {
     public static final String TEXT_USE_CAPTION="text:use-caption";
     public static final String TEXT_CAPTION_SEQUENCE_NAME="text:caption-sequence-name";
     public static final String TEXT_STRING_VALUE="text:string-value";
+	public static final String TEXT_INDEX_NAME = "text:index-name";
     public static final String TEXT_KEY1="text:key1";
     public static final String TEXT_KEY2="text:key2";
     public static final String TEXT_LEVEL="text:level";
@@ -372,10 +384,18 @@ public class XMLString {
     public static final String TEXT_LIST_LEVEL_POSITION_AND_SPACE_MODE="text:list-level-position-and-space-mode"; // oasis 1.2
     public static final String TEXT_LABEL_FOLLOWED_BY="text:label-followed-by"; // oasis 1.2
     public static final String TEXT_LIST_TAB_STOP_POSITION="text:list-tab-stop-position"; // oasis 1.2
-    
+
+    public static final String TEXT_PREFIX="text:prefix";
+    public static final String TEXT_SUFFIX="text:suffix";
+    public static final String TEXT_NUMBERED_ENTRIES="text:numbered-entries";
+    public static final String TEXT_SORT_BY_POSITION="text:sort-by-position";
+    public static final String TEXT_SORT_ALGORITHM="text:sort-algorithm";
+    public static final String TEXT_KEY="text:key";
+    public static final String TEXT_SORT_ASCENDING="text:sort-ascending";
     public static final String TEXT_IDENTIFIER="text:identifier";
     public static final String TEXT_BIBLIOGRAPHY_TYPE="text:bibliography-type";
     public static final String TEXT_BIBILIOGRAPHIC_TYPE="text:bibiliographic-type"; // bug in OOo 1.0
+    public static final String TEXT_BIBLIOGRAPHY_DATA_FIELD="text:bibliography-data-field";
     public static final String TEXT_ADDRESS="text:address";
     public static final String TEXT_ANNOTE="text:annote";
     public static final String TEXT_AUTHOR="text:author";
@@ -465,5 +485,9 @@ public class XMLString {
 	public static final String MATH="math";
     public static final String SEMANTICS="semantics";
 	public static final String ANNOTATION="annotation";
+	
+	// officeooo namespace (LibreOffice specific)
+	public static final String OFFICEOOO_RSID = "officeooo:rsid";
+	public static final String OFFICEOOO_PARAGRAPH_RSID = "officeooo:paragraph-rsid";
     
 }
