@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2015 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-16)
+ *  Version 1.6 (2015-02-16)
  *
  */
 
@@ -31,7 +31,6 @@ import java.io.File;
 import java.io.InputStream;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
-import java.lang.Math;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URLEncoder;
@@ -44,7 +43,6 @@ import java.util.Arrays;
 import java.util.Date;
 import java.util.Locale;
 import java.util.Set;
-//import java.util.Hashtable;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
@@ -143,28 +141,6 @@ public class Misc{
         return int2alph(number,bLetterSync).toUpperCase();
     }
     
-    public static final int getPosInteger(String sInteger, int nDefault){
-        int n;
-        try {
-            n=Integer.parseInt(sInteger);
-        }
-        catch (NumberFormatException e) {
-            return nDefault;
-        }
-        return n>0 ? n : nDefault;
-    }
-    
-    public static final float getFloat(String sFloat, float fDefault){
-        float f;
-        try {
-            f=Float.parseFloat(sFloat);
-        }
-        catch (NumberFormatException e) {
-            return fDefault;
-        }
-        return f;
-    }
-    
     public static final int getIntegerFromHex(String sHex, int nDefault){
         int n;
         try {
@@ -176,107 +152,90 @@ public class Misc{
         return n;
     }
 	
-    public static String truncateLength(String sValue) {
-        if (sValue.endsWith("inch")) {
-            // Cut of inch to in
-            return sValue.substring(0,sValue.length()-2);
+    /** Make a file name TeX friendly, replacing offending characters
+     * 
+     * @param sFileName the file name
+     * @param sDefault a default name to use if no characters remains after filtering
+     * @return the modified file name
+     */
+    public static String makeTeXFriendly(String sFileName, String sDefault) {
+        StringBuilder builder = new StringBuilder();
+        for (int i=0; i<sFileName.length(); i++) {
+            char c = sFileName.charAt(i);
+            if ((c>='a' && c<='z') || (c>='A' && c<='Z') || (c>='0' && c<='9')) {
+                builder.append(c);
+            }
+            else {
+            	switch (c) {
+            	case '.': builder.append('.'); break;
+            	case '-': builder.append('-'); break;
+            	case ' ' : builder.append('-'); break;
+            	case '_' : builder.append('-'); break;
+            	// Replace accented and national characters
+            	case '\u00c0' : builder.append('A'); break;
+            	case '\u00c1' : builder.append('A'); break;
+            	case '\u00c2' : builder.append('A'); break;
+            	case '\u00c3' : builder.append('A'); break;
+            	case '\u00c4' : builder.append("AE"); break;
+            	case '\u00c5' : builder.append("AA"); break;
+            	case '\u00c6' : builder.append("AE"); break;
+            	case '\u00c7' : builder.append('C'); break;
+            	case '\u00c8' : builder.append('E'); break;
+            	case '\u00c9' : builder.append('E'); break;
+            	case '\u00ca' : builder.append('E'); break;
+            	case '\u00cb' : builder.append('E'); break;
+            	case '\u00cc' : builder.append('I'); break;
+            	case '\u00cd' : builder.append('I'); break;
+            	case '\u00ce' : builder.append('I'); break;
+            	case '\u00cf' : builder.append('I'); break;
+            	case '\u00d0' : builder.append('D'); break;
+            	case '\u00d1' : builder.append('N'); break;
+            	case '\u00d2' : builder.append('O'); break;
+            	case '\u00d3' : builder.append('O'); break;
+            	case '\u00d4' : builder.append('O'); break;
+            	case '\u00d5' : builder.append('O'); break;
+            	case '\u00d6' : builder.append("OE"); break;
+            	case '\u00d8' : builder.append("OE"); break;
+            	case '\u00d9' : builder.append('U'); break;
+            	case '\u00da' : builder.append('U'); break;
+            	case '\u00db' : builder.append('U'); break;
+            	case '\u00dc' : builder.append("UE"); break;
+            	case '\u00dd' : builder.append('Y'); break;
+            	case '\u00df' : builder.append("sz"); break;
+            	case '\u00e0' : builder.append('a'); break;
+            	case '\u00e1' : builder.append('a'); break;
+            	case '\u00e2' : builder.append('a'); break;
+            	case '\u00e3' : builder.append('a'); break;
+            	case '\u00e4' : builder.append("ae"); break;
+            	case '\u00e5' : builder.append("aa"); break;
+            	case '\u00e6' : builder.append("ae"); break;
+            	case '\u00e7' : builder.append('c'); break;
+            	case '\u00e8' : builder.append('e'); break;
+            	case '\u00e9' : builder.append('e'); break;
+            	case '\u00ea' : builder.append('e'); break;
+            	case '\u00eb' : builder.append('e'); break;
+            	case '\u00ec' : builder.append('i'); break;
+            	case '\u00ed' : builder.append('i'); break;
+            	case '\u00ee' : builder.append('i'); break;
+            	case '\u00ef' : builder.append('i'); break;
+            	case '\u00f0' : builder.append('d'); break;
+            	case '\u00f1' : builder.append('n'); break;
+            	case '\u00f2' : builder.append('o'); break;
+            	case '\u00f3' : builder.append('o'); break;
+            	case '\u00f4' : builder.append('o'); break;
+            	case '\u00f5' : builder.append('o'); break;
+            	case '\u00f6' : builder.append("oe"); break;
+            	case '\u00f8' : builder.append("oe"); break;
+            	case '\u00f9' : builder.append('u'); break;
+            	case '\u00fa' : builder.append('u'); break;
+            	case '\u00fb' : builder.append('u'); break;
+            	case '\u00fc' : builder.append("ue"); break;
+            	case '\u00fd' : builder.append('y'); break;
+            	case '\u00ff' : builder.append('y'); break;
+            	}
+            }
         }
-        else {
-            return sValue;
-        }
-    }
-	
-    public static boolean isZero(String sValue) {
-    	return Math.abs(getFloat(sValue.substring(0, sValue.length()-2),0))<0.001;
-    }
-    
-    // Return units per inch for some unit
-    private static final float getUpi(String sUnit) {
-        if ("in".equals(sUnit)) { return 1.0F; }
-        else if ("mm".equals(sUnit)) { return 25.4F; }
-        else if ("cm".equals(sUnit)) { return 2.54F; }
-        else if ("pc".equals(sUnit)) { return 6F; }
-        else { return 72; } // pt or unknown
-    }
-	
-    // Convert a length to px assuming 96ppi (cf. css spec)
-    // Exception: Never return less than 1px
-    public static final String length2px(String sLength) {
-        if (sLength.equals("0")) { return "0"; }
-        float fLength=getFloat(sLength.substring(0,sLength.length()-2),1);
-        String sUnit=sLength.substring(sLength.length()-2);
-        float fPixels = 96.0F/getUpi(sUnit)*fLength;
-        if (Math.abs(fPixels)<0.01) {
-            // Very small, treat as zero
-            return "0";
-        }
-        else if (fPixels>0) {
-            // Never return less that 1px
-            return Float.toString(fPixels<1 ? 1 : fPixels)+"px";
-        }
-        else {
-            // Or above -1px
-            return Float.toString(fPixels>-1 ? -1 : fPixels)+"px";
-        }
-    }
-    
-    // Divide dividend by divisor and return the quotient as an integer percentage
-    // (never below 1% except if the dividend is zero)
-    public static final String divide(String sDividend, String sDivisor) {
-    	return divide(sDividend,sDivisor,false);
-    }
-
-    // Divide dividend by divisor and return the quotient as an integer percentage
-    // (never below 1% except if the dividend is zero, and never above 100% if last parameter is true)
-    public static final String divide(String sDividend, String sDivisor, boolean bMax100) {
-        if (sDividend.equals("0")) { return "0%"; }
-        if (sDivisor.equals("0")) { return "100%"; }
-
-        float fDividend=getFloat(sDividend.substring(0,sDividend.length()-2),1);
-        String sDividendUnit=sDividend.substring(sDividend.length()-2);
-        float fDivisor=getFloat(sDivisor.substring(0,sDivisor.length()-2),1);
-        String sDivisorUnit=sDivisor.substring(sDivisor.length()-2);
-        int nPercent = Math.round(100*fDividend*getUpi(sDivisorUnit)/fDivisor/getUpi(sDividendUnit));
-        if (bMax100 && nPercent>100) {
-        	return "100%";
-        }
-        else if (nPercent>0) {
-        	return Integer.toString(nPercent)+"%";
-        }
-        else {
-        	return "1%";
-        }
-    }
-    
-    public static final String multiply(String sPercent, String sLength){
-        if (sLength.equals("0")) { return "0"; }
-        float fPercent=getFloat(sPercent.substring(0,sPercent.length()-1),1);
-        float fLength=getFloat(sLength.substring(0,sLength.length()-2),1);
-        String sUnit=sLength.substring(sLength.length()-2);
-        return Float.toString(fPercent*fLength/100)+sUnit;
-    }
-
-    public static final String add(String sLength1, String sLength2){
-        if (sLength1.equals("0")) { return sLength2; }
-        if (sLength2.equals("0")) { return sLength1; }
-        float fLength1=getFloat(sLength1.substring(0,sLength1.length()-2),1);
-        String sUnit1=sLength1.substring(sLength1.length()-2);
-        float fLength2=getFloat(sLength2.substring(0,sLength2.length()-2),1);
-        String sUnit2=sLength2.substring(sLength2.length()-2);
-        // Use unit from sLength1:
-        return Float.toString(fLength1+getUpi(sUnit1)/getUpi(sUnit2)*fLength2)+sUnit1;
-    }
-
-    public static final String sub(String sLength1, String sLength2){
-        return add(sLength1,multiply("-100%",sLength2));
-    }
-
-    public static boolean isLessThan(String sThis, String sThat) {
-        return sub(sThis,sThat).startsWith("-");
-    }	
-    
-    public static String abs(String sLength) {
-        return sLength.startsWith("-") ? sLength.substring(1) : sLength;
+        return builder.length()>0 ? builder.toString() : sDefault; 
     }
 
     /*
@@ -297,20 +256,22 @@ public class Misc{
         return name;
     }
     
+    /** Get the path part of an URL
+     * 
+     * @param sURL the URL from which the filename should be extracted
+     * @return the file name
+     */
+    public static final String getPath(String sURL) {
+    	return sURL.substring(0,sURL.lastIndexOf('/')+1);
+    }
+    
     /** Get the file name part of an URL
      * 
      * @param sURL the URL from which the filename should be extracted
      * @return the file name
      */
     public static final String getFileName(String sURL) {
-    	try {
-			URI uri = new URI(sURL);
-			String sPath = uri.getPath();
-			return sPath.substring(sPath.lastIndexOf('/')+1);
-		} catch (URISyntaxException e) {
-			e.printStackTrace();
-			return "";
-		}    	
+    	return sURL.substring(sURL.lastIndexOf('/')+1);
     }
     
     /** Get the file extension from an URL
@@ -329,10 +290,9 @@ public class Misc{
     	}
     }
 	
-    public static final String removeExtension(String sName) {
-        int n = sName.lastIndexOf(".");
-        if (n<0) { return sName; }
-        return sName.substring(0,n);
+    public static final String removeExtension(String sURL) {
+    	String sExt = getFileExtension(sURL);
+    	return sURL.substring(0, sURL.length()-sExt.length());
     }
 	
      /*
@@ -474,7 +434,14 @@ public class Misc{
     	return "error";
     }
  
-    
+    public static File urlToFile(String sUrl) {
+        try {
+            return new File(new URI(sUrl));
+        }
+        catch (URISyntaxException e) {
+            return new File(".");
+        }
+    }
 	
     /** <p>Read an <code>InputStream</code> into a <code>byte</code>array</p>
      *  @param is   the <code>InputStream</code> to read
@@ -494,6 +461,17 @@ public class Misc{
         }
         return baos.toByteArray();
     }
+
+	public static final int getPosInteger(String sInteger, int nDefault){
+	    int n;
+	    try {
+	        n=Integer.parseInt(sInteger);
+	    }
+	    catch (NumberFormatException e) {
+	        return nDefault;
+	    }
+	    return n>0 ? n : nDefault;
+	}
 	
 
 
