@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-18)
+ *  Version 1.6.1 (2018-08-08)
  *
  */
 
@@ -192,6 +192,8 @@ public class Converter extends ConverterBase {
     protected MathConverter getMathCv() { return mathCv; }
 	
     protected int getType() { return nType; }
+    
+    public boolean isHTML5() { return nType>=XhtmlDocument.HTML5; }
 	
     protected int getOutFileIndex() { return nOutFileIndex; }
     
@@ -226,6 +228,18 @@ public class Converter extends ConverterBase {
     }
 	
     protected Element createElement(String s) { return htmlDOM.createElement(s); }
+    
+    Element createAlternativeElement(String sHTML5, String sHTML) {
+		if (isHTML5() && !(isOPS() && config.avoidHtml5())) {
+			// Exception is for compatibility with older EPUB readers not understanding HTML5 tags
+			return createElement(sHTML5);
+		}
+		else {
+			return createElement(sHTML);
+		}
+
+    }
+
 	
     protected Text createTextNode(String s) { return htmlDOM.createTextNode(s); }
 	
@@ -236,9 +250,9 @@ public class Converter extends ConverterBase {
     public void setOPS(boolean b) { bOPS = true; }
     
     public boolean isOPS() { return bOPS; }
-	
-    @Override public void convertInner() throws IOException {      
-        sTargetFileName = Misc.trimDocumentName(sTargetFileName,XhtmlDocument.getExtension(nType));
+    
+    @Override public void convertInner() throws IOException {
+        sTargetFileName = Misc.trimDocumentName(sTargetFileName,XhtmlDocument.getExtension(nType));    		
 		
         outFiles = new Vector<XhtmlDocument>();
         nOutFileIndex = -1;
@@ -262,7 +276,7 @@ public class Converter extends ConverterBase {
         imageConverter.addAcceptedFormat(MIMETypes.JPEG);
         imageConverter.addAcceptedFormat(MIMETypes.GIF);
         
-        if (nType==XhtmlDocument.HTML5) { // HTML supports SVG as well
+        if (isHTML5()) { // HTML supports SVG as well
         	imageConverter.setDefaultVectorFormat(MIMETypes.SVG);
         }
 
@@ -351,7 +365,7 @@ public class Converter extends ConverterBase {
         
         // Load MathJax
         // TODO: Should we support different configurations of MathJax?
-        if ((nType==XhtmlDocument.HTML5 || nType==XhtmlDocument.XHTML_MATHML) && config.useMathJax()) {
+        if ((isHTML5() || nType==XhtmlDocument.XHTML_MATHML) && config.useMathJax()) {
         	for (int i=0; i<=nOutFileIndex; i++) {
         		if (outFiles.get(i).hasMath()) {
         			XhtmlDocument doc = outFiles.get(i);
@@ -360,7 +374,8 @@ public class Converter extends ConverterBase {
         				Element script = doc.getContentDOM().createElement("script");
         				head.appendChild(script);
         				script.setAttribute("type", "text/javascript");
-        				script.setAttribute("src", "http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML");
+        				script.setAttribute("src", "https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.4/latest.js?config=TeX-MML-AM_CHTML");
+        				script.setAttribute("async","async");
         			}
         		}
         	}
@@ -643,6 +658,7 @@ public class Converter extends ConverterBase {
         htmlDOM = htmlDoc.getContentDOM();
         Element rootElement = htmlDOM.getDocumentElement();
         styleCv.applyDefaultLanguage(rootElement);
+        addEpubNs(rootElement);
         rootElement.insertBefore(htmlDOM.createComment(
              "This file was converted to xhtml by "
              + (ofr.isText() ? "Writer" : (ofr.isSpreadsheet() ? "Calc" : "Impress"))
@@ -676,7 +692,7 @@ public class Converter extends ConverterBase {
         		meta.setAttribute("content","text/html; charset="+htmlDoc.getEncoding().toLowerCase());
         		head.appendChild(meta);
         	}
-        	else if (nType==XhtmlDocument.HTML5) {
+        	else if (isHTML5()) {
         		// The encoding should be UTF-8, but we still respect the user's setting
         		Element meta = htmlDOM.createElement("meta");
         		meta.setAttribute("charset",htmlDoc.getEncoding().toUpperCase());
@@ -776,6 +792,20 @@ public class Converter extends ConverterBase {
         
         return htmlDoc.getContentNode();
     }
+    
+    // Add epub namespace for the purpose of semantic inflection in EPUB 3
+    public void addEpubNs(Element elm) {
+    	if (bOPS && isHTML5()) {
+           	elm.setAttribute("xmlns:epub", "http://www.idpf.org/2007/ops");
+    	}    	
+    }
+    
+	// Add a type from the structural semantics vocabulary of EPUB 3
+    public void addEpubType(Element elm, String sType) {
+    	if (bOPS && isHTML5() && sType!=null) {
+    		elm.setAttribute("epub:type", sType);
+    	}
+    }
 	
     // create a target
     public Element createTarget(String sId) {
@@ -790,6 +820,11 @@ public class Converter extends ConverterBase {
         node.setAttribute("id",targetNames.getExportName(sId));
         targets.put(sId, new Integer(nOutFileIndex));
     }
+    
+    // get at target id
+    String getTarget(String sId) {
+    	return targetNames.getExportName(sId);
+    }
 
     // create an internal link
     public Element createLink(String sId) {
