@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-24)
+ *  Version 1.6 (2018-05-23)
  *
  */
  
@@ -47,6 +47,8 @@ import java.util.Vector;
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 
+import javax.xml.bind.DatatypeConverter;
+
 import org.xml.sax.SAXException;
 
 import org.w3c.dom.Document;
@@ -54,6 +56,7 @@ import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.w3c.dom.Element;
 
+import writer2latex.util.Calc;
 import writer2latex.util.Misc;
 import writer2latex.util.CSVList;
 import writer2latex.util.SimpleXMLParser;
@@ -100,6 +103,7 @@ public class DrawConverter extends ConverterHelper {
     private String sImageSplit;
     private boolean bCoverImage;
     private boolean bEmbedSVG;
+    private boolean bEmbedImg;
 
     // Embedded SVG images for recycling are collected here
     private HashMap<String,Element> svgImages = new HashMap<String,Element>();
@@ -113,7 +117,7 @@ public class DrawConverter extends ConverterHelper {
     private Vector<Element> fullscreenFrames = new Vector<Element>();
     // This flag determines whether to collect full screen images or insert them immediately
     private boolean bCollectFullscreenFrames = true;
-	
+
     public DrawConverter(OfficeReader ofr, XhtmlConfig config, Converter converter) {
         super(ofr,config,converter);
         // We can only handle one form; pick an arbitrary one.
@@ -130,6 +134,7 @@ public class DrawConverter extends ConverterHelper {
         sImageSplit = config.imageSplit();
         bCoverImage = config.coverImage();
         bEmbedSVG = config.embedSVG();
+        bEmbedImg = config.embedImg();
     }
     
     ///////////////////////////////////////////////////////////////////////
@@ -455,9 +460,9 @@ public class DrawConverter extends ConverterHelper {
         		// It is if the image width exceeds a certain percentage of the current text width and the height is
         		// greater than 1.33*the width (recommended by Michel "Coolmicro")
         		if (sWidth!=null && sHeight!=null &&
-        				Misc.sub(Misc.multiply("133%",sWidth), sHeight).startsWith("-") &&
-        				Misc.sub(Misc.multiply(sImageSplit,converter.getContentWidth()),
-        						Misc.multiply(sScale,Misc.truncateLength(sWidth))).startsWith("-")) {
+        				Calc.sub(Calc.multiply("133%",sWidth), sHeight).startsWith("-") &&
+        				Calc.sub(Calc.multiply(sImageSplit,converter.getContentWidth()),
+        						Calc.multiply(sScale,Calc.truncateLength(sWidth))).startsWith("-")) {
         			fullscreenFrames.add(onode);
         			return;
         		}
@@ -487,7 +492,7 @@ public class DrawConverter extends ConverterHelper {
         
         // Create the image (sFileName contains the file name)
         Element imageElement = null;
-        if (converter.nType==XhtmlDocument.HTML5 && bEmbedSVG && bgd!=null && MIMETypes.SVG.equals(bgd.getMIMEType())) {
+        if (converter.isHTML5() && bEmbedSVG && bgd!=null && MIMETypes.SVG.equals(bgd.getMIMEType())) {
         	// In HTML5 we may embed SVG images directly in the document
         	if (bgd.isRecycled()) {
         		// Get from the cache (actually we are certain it is there)
@@ -516,21 +521,28 @@ public class DrawConverter extends ConverterHelper {
         	}
         }
         else {
-        	// In all other cases, create an img element
-            if (bgd!=null && !bgd.isLinked() && !bgd.isRecycled()) { converter.addDocument(bgd); }
+        	 // In all other cases, create an img element
+        	if (bgd!=null && !bgd.isLinked() && !bgd.isRecycled() && !bEmbedImg) { converter.addDocument(bgd); }
         	Element image = converter.createElement("img");
         	String sName = Misc.getAttribute(getFrame(onode),XMLString.DRAW_NAME);
         	converter.addTarget(image,sName+"|graphic");
-        	image.setAttribute("src",sFileName);
-        
+        	if (!bEmbedImg || bgd.isLinked()) {
+        		image.setAttribute("src",sFileName);
+        	}
+        	else {
+        		StringBuilder buf = new StringBuilder();
+        		buf.append("data:").append(bgd.getMIMEType()).append(";base64,")
+        			.append(DatatypeConverter.printBase64Binary(bgd.getData()));
+        		image.setAttribute("src", buf.toString());
+        	}
         	// Add alternative text, using either alt.text, name or file name
         	Element desc = Misc.getChildByTagName(frame,XMLString.SVG_DESC);
         	if (desc==null) {
-        		desc = Misc.getChildByTagName(frame,XMLString.SVG_TITLE);        	
+        		desc = Misc.getChildByTagName(frame,XMLString.SVG_TITLE);
         	}
         	String sAltText = desc!=null ? Misc.getPCDATA(desc) : (sName!=null ? sName : sFileName);
         	image.setAttribute("alt",sAltText);
-        	imageElement = image;
+        	imageElement = image; 
         }
         
         if (imageElement!=null) {
@@ -931,18 +943,18 @@ public class DrawConverter extends ConverterHelper {
     		if (style!=null) {
     			// Subtract padding
     			String s = style.getProperty(XMLString.FO_PADDING_LEFT);
-    			if (s!=null) sWidth = Misc.sub(sWidth, s);
+    			if (s!=null) sWidth = Calc.sub(sWidth, s);
     			s = style.getProperty(XMLString.FO_PADDING_RIGHT);
-    			if (s!=null) sWidth = Misc.sub(sWidth, s);
+    			if (s!=null) sWidth = Calc.sub(sWidth, s);
     			s = style.getProperty(XMLString.FO_PADDING);
-    			if (s!=null) sWidth = Misc.sub(sWidth, Misc.multiply("200%", s));
+    			if (s!=null) sWidth = Calc.sub(sWidth, Calc.multiply("200%", s));
     			// Subtract border
     			s = style.getProperty(XMLString.FO_BORDER_LEFT);
-    			if (s!=null) sWidth = Misc.sub(sWidth, getTableCv().borderWidth(s));
+    			if (s!=null) sWidth = Calc.sub(sWidth, getTableCv().borderWidth(s));
     			s = style.getProperty(XMLString.FO_BORDER_RIGHT);
-    			if (s!=null) sWidth = Misc.sub(sWidth, getTableCv().borderWidth(s));
+    			if (s!=null) sWidth = Calc.sub(sWidth, getTableCv().borderWidth(s));
     			s = style.getProperty(XMLString.FO_BORDER);
-    			if (s!=null) sWidth = Misc.sub(sWidth, Misc.multiply("200%", getTableCv().borderWidth(s)));
+    			if (s!=null) sWidth = Calc.sub(sWidth, Calc.multiply("200%", getTableCv().borderWidth(s)));
     		}
 			return sWidth;
     	}
@@ -956,18 +968,18 @@ public class DrawConverter extends ConverterHelper {
         	if (style!=null) {
         		// Subtract padding
                 String s = style.getProperty(XMLString.FO_PADDING_TOP);
-                if (s!=null) sHeight = Misc.sub(sHeight, s);
+                if (s!=null) sHeight = Calc.sub(sHeight, s);
                 s = style.getProperty(XMLString.FO_PADDING_BOTTOM);
-                if (s!=null) sHeight = Misc.sub(sHeight, s);
+                if (s!=null) sHeight = Calc.sub(sHeight, s);
                 s = style.getProperty(XMLString.FO_PADDING);
-                if (s!=null) sHeight = Misc.sub(sHeight, Misc.multiply("200%", s));
+                if (s!=null) sHeight = Calc.sub(sHeight, Calc.multiply("200%", s));
                 // Subtract border
                 s = style.getProperty(XMLString.FO_BORDER_TOP);
-                if (s!=null) sHeight = Misc.sub(sHeight, getTableCv().borderWidth(s));
+                if (s!=null) sHeight = Calc.sub(sHeight, getTableCv().borderWidth(s));
                 s = style.getProperty(XMLString.FO_BORDER_BOTTOM);
-                if (s!=null) sHeight = Misc.sub(sHeight, getTableCv().borderWidth(s));
+                if (s!=null) sHeight = Calc.sub(sHeight, getTableCv().borderWidth(s));
                 s = style.getProperty(XMLString.FO_BORDER);
-                if (s!=null) sHeight = Misc.sub(sHeight, Misc.multiply("200%", getTableCv().borderWidth(s)));
+                if (s!=null) sHeight = Calc.sub(sHeight, Calc.multiply("200%", getTableCv().borderWidth(s)));
             }
         	return sHeight;
         }
@@ -1007,7 +1019,7 @@ public class DrawConverter extends ConverterHelper {
     		else {
     			String sWidth = getFrameWidth(node, ofr.getFrameStyle(node.getAttribute(XMLString.DRAW_STYLE_NAME)));			
     			if (sWidth!=null) {    
-    				props.addValue("width", Misc.divide(Misc.multiply(sScale,Misc.truncateLength(sWidth)),converter.getContentWidth()));
+    				props.addValue("width", Calc.divide(Calc.multiply(sScale,Calc.truncateLength(sWidth)),converter.getContentWidth()));
     			}
     			return sWidth;
     		}
@@ -1028,9 +1040,9 @@ public class DrawConverter extends ConverterHelper {
     	StyleWithProperties style = ofr.getFrameStyle(node.getAttribute(XMLString.DRAW_STYLE_NAME));
     	if (style!=null) {
     		String s = style.getProperty(XMLString.FO_MARGIN_TOP);
-    		if (s!=null) sX=Misc.sub(sX,s);
+    		if (s!=null) sX=Calc.sub(sX,s);
     		s = style.getProperty(XMLString.FO_MARGIN_LEFT);
-    		if (s!=null) sY=Misc.sub(sY,s);
+    		if (s!=null) sY=Calc.sub(sY,s);
     	}
     	
         props.addValue("position","absolute");
@@ -1148,10 +1160,10 @@ public class DrawConverter extends ConverterHelper {
     // TODO: Move to ConverterHelper.java
     private String scale(String s) {
         if (bConvertToPx) {
-            return Misc.length2px(Misc.multiply(sScale,Misc.truncateLength(s)));
+            return Calc.length2px(Calc.multiply(sScale,Calc.truncateLength(s)));
         }
         else {
-            return Misc.multiply(sScale,Misc.truncateLength(s));
+            return Calc.multiply(sScale,Calc.truncateLength(s));
         }
     }
 }
