@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2012 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2012-04-12)
+ *  Version 1.6 (2018-05-24)
  *
  */
 
@@ -32,6 +32,7 @@ import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.w3c.dom.Element;
 
+import writer2latex.util.Calc;
 import writer2latex.util.Misc;
 import writer2latex.util.SimpleInputBuffer;
 import writer2latex.office.XMLString;
@@ -177,8 +178,11 @@ public class TableConverter extends ConverterHelper {
     private Element createTable(TableReader tblr) {
         Element table = converter.createElement("table");
         // Apply table style
-        // IE needs the cellspacing attribute, as it doesn't understand the css border-spacing attribute
-        table.setAttribute("cellspacing","0");
+        // Older versions of IE needs the cellspacing attribute, as it doesn't understand the css border-spacing attribute
+        // We cannot do this with HTML5
+        if (!converter.isHTML5()) {
+        	table.setAttribute("cellspacing","0");
+        }
         applyTableStyle(tblr.getTableStyleName(), table, tblr.isSubTable());
         return table;
     }
@@ -206,7 +210,7 @@ public class TableConverter extends ConverterHelper {
         if (config.tableSize()!=XhtmlConfig.NONE) {
         	if (view.getRelTableWidth()!=null || config.tableSize()==XhtmlConfig.RELATIVE || bFirstRowColSpan) {
         		Element colgroup = hnode;
-        		if (converter.nType==XhtmlDocument.HTML5) {
+        		if (converter.isHTML5()) {
         			// Polyglot HTML5 documents must use an explicit colgroup
         			colgroup = converter.createElement("colgroup");
         			hnode.appendChild(colgroup);
@@ -236,7 +240,7 @@ public class TableConverter extends ConverterHelper {
         if (nBodyStart==0 || nBodyStart==nRowCount) {
             // all body or all head
         	Element tbody = hnode;
-        	if (converter.nType==XhtmlDocument.HTML5) {
+        	if (converter.isHTML5()) {
         		// Polyglot HTML5 documents must use an explicit tbody
         		tbody = converter.createElement("tbody");
         		hnode.appendChild(tbody);
@@ -348,7 +352,7 @@ public class TableConverter extends ConverterHelper {
                     if (sWidth!=null) {
                         if (config.tableSize()==XhtmlConfig.RELATIVE){
                         	// Force relative width
-                        	sWidth=Misc.divide(sWidth, converter.getContentWidth(), true);
+                        	sWidth=Calc.divide(sWidth, converter.getContentWidth(), true);
                         	info.props.addValue("width",sWidth);
                         }
                         else {
@@ -413,31 +417,31 @@ public class TableConverter extends ConverterHelper {
                 // "total cell width" - "border" - "padding"
                 String s = style.getProperty(XMLString.FO_PADDING_LEFT);
                 if (s!=null) {
-                    sEdge=Misc.add(sEdge,getTableSc().colScale(s));
+                    sEdge=Calc.add(sEdge,getTableSc().colScale(s));
                 }
                 s = style.getProperty(XMLString.FO_PADDING_RIGHT);
                 if (s!=null) { 
-                    sEdge=Misc.add(sEdge,getTableSc().colScale(s));
+                    sEdge=Calc.add(sEdge,getTableSc().colScale(s));
                 }
                 s = style.getProperty(XMLString.FO_PADDING);
                 if (s!=null) {
-                    sEdge=Misc.add(sEdge,Misc.multiply("200%",getTableSc().colScale(s)));
+                    sEdge=Calc.add(sEdge,Calc.multiply("200%",getTableSc().colScale(s)));
                 }
                 s = style.getProperty(XMLString.FO_BORDER_LEFT);
                 if (s!=null) {
-                    sEdge=Misc.add(sEdge,getTableSc().colScale(borderWidth(s)));
+                    sEdge=Calc.add(sEdge,getTableSc().colScale(borderWidth(s)));
                 }
                 s = style.getProperty(XMLString.FO_BORDER_RIGHT);
                 if (s!=null) { 
-                    sEdge=Misc.add(sEdge,getTableSc().colScale(borderWidth(s)));
+                    sEdge=Calc.add(sEdge,getTableSc().colScale(borderWidth(s)));
                 }
                 s = style.getProperty(XMLString.FO_BORDER);
                 if (s!=null) {
-                    sEdge=Misc.add(sEdge,Misc.multiply("200%",getTableSc().colScale(borderWidth(s))));
+                    sEdge=Calc.add(sEdge,Calc.multiply("200%",getTableSc().colScale(borderWidth(s))));
                 }
 
                 if (sTotalWidth!=null) {
-                    info.props.addValue("width",Misc.sub(getTableSc().colScale(sTotalWidth),sEdge));
+                    info.props.addValue("width",Calc.sub(getTableSc().colScale(sTotalWidth),sEdge));
                 }
             }
 
@@ -477,7 +481,7 @@ public class TableConverter extends ConverterHelper {
                 return in.getNumber()+in.getIdentifier();
             }
             // skip other characters
-            while (in.peekChar()!=' ' && in.peekChar()!='\0') { } 
+            while (in.peekChar()!=' ' && in.peekChar()!='\0') { in.getChar(); } 
         }
         return "0";
     }
