@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-23)
+ *  Version 1.6.1 (2018-08-13)
  *
  */
 
@@ -41,7 +41,7 @@ import writer2latex.util.Misc;
 
 public class XhtmlConfig extends writer2latex.base.ConfigBase {
     // Implement configuration methods
-    protected int getOptionCount() { return 56; }
+    protected int getOptionCount() { return 62; }
     protected String getDefaultConfigPath() { return "/writer2latex/xhtml/config/"; }
 	
     // Override setOption: To be backwards compatible, we must accept options
@@ -120,42 +120,48 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     private static final int TABLE_FORMATTING = 17;
     private static final int TABLE_SIZE = 18;
     private static final int LIST_FORMATTING = 19;
-    private static final int USE_DEFAULT_FONT = 20;
-    private static final int DEFAULT_FONT_NAME = 21;
-    private static final int USE_DUBLIN_CORE = 22;
-    private static final int NOTES = 23;
-    private static final int DISPLAY_HIDDEN_TEXT = 24;
-    private static final int CONVERT_TO_PX = 25;
-    private static final int SCALING = 26;
-    private static final int COLUMN_SCALING = 27;
-    private static final int RELATIVE_FONT_SIZE = 28;
-    private static final int FONT_SCALING = 29;
-    private static final int FLOAT_OBJECTS = 30;
-    private static final int TABSTOP_STYLE = 31;
-    private static final int FORMULAS = 32;
-    private static final int ENDNOTES_HEADING = 33;
-    private static final int FOOTNOTES_HEADING = 34;
-    private static final int EXTERNAL_TOC_DEPTH = 35;
-    private static final int INCLUDE_TOC = 36;
-    private static final int SPLIT_LEVEL = 37;
-    private static final int REPEAT_LEVELS = 38;
-    private static final int PAGE_BREAK_SPLIT = 39;
-    private static final int SPLIT_AFTER = 40;
-    private static final int IMAGE_SPLIT = 41;
-    private static final int COVER_IMAGE = 42;
-    private static final int EMBED_SVG = 43;
-    private static final int USE_MATHJAX = 44;
-    private static final int CALC_SPLIT = 45;
-    private static final int DISPLAY_HIDDEN_SHEETS = 46;
-    private static final int DISPLAY_HIDDEN_ROWS_COLS = 47;
-    private static final int DISPLAY_FILTERED_ROWS_COLS = 48;
-    private static final int APPLY_PRINT_RANGES = 49;
-    private static final int USE_TITLE_AS_HEADING = 50;
-    private static final int USE_SHEET_NAMES_AS_HEADINGS = 51;
-    private static final int SAVE_IMAGES_IN_SUBDIR = 52;
-    private static final int UPLINK = 53;
-    private static final int DIRECTORY_ICON = 54;
-    private static final int DOCUMENT_ICON = 55;
+    private static final int MAX_WIDTH = 20;
+    private static final int USE_DEFAULT_FONT = 21;
+    private static final int DEFAULT_FONT_NAME = 22;
+    private static final int USE_DUBLIN_CORE = 23;
+    private static final int NOTES = 24;
+    private static final int DISPLAY_HIDDEN_TEXT = 25;
+    private static final int CONVERT_TO_PX = 26;
+    private static final int SCALING = 27;
+    private static final int COLUMN_SCALING = 28;
+    private static final int RELATIVE_FONT_SIZE = 29;
+    private static final int FONT_SCALING = 30;
+    private static final int FLOAT_OBJECTS = 31;
+    private static final int TABSTOP_STYLE = 32;
+    private static final int FORMULAS = 33;
+    private static final int ENDNOTES_HEADING = 34;
+    private static final int FOOTNOTES_HEADING = 35;
+    private static final int EXTERNAL_TOC_DEPTH = 36;
+    private static final int INCLUDE_TOC = 37;
+    private static final int INCLUDE_NCX = 38;
+    private static final int SPLIT_LEVEL = 39;
+    private static final int REPEAT_LEVELS = 40;
+    private static final int PAGE_BREAK_SPLIT = 41;
+    private static final int SPLIT_AFTER = 42;
+    private static final int IMAGE_SPLIT = 43;
+    private static final int COVER_IMAGE = 44;
+    private static final int EMBED_SVG = 45;
+    private static final int EMBED_IMG = 46;
+    private static final int USE_MATHJAX = 47;
+    private static final int CALC_SPLIT = 48;
+    private static final int DISPLAY_HIDDEN_SHEETS = 49;
+    private static final int DISPLAY_HIDDEN_ROWS_COLS = 50;
+    private static final int DISPLAY_FILTERED_ROWS_COLS = 51;
+    private static final int APPLY_PRINT_RANGES = 52;
+    private static final int USE_TITLE_AS_HEADING = 53;
+    private static final int USE_SHEET_NAMES_AS_HEADINGS = 54;
+    private static final int SAVE_IMAGES_IN_SUBDIR = 55;
+    private static final int UPLINK = 56;
+    private static final int DIRECTORY_ICON = 57;
+    private static final int DOCUMENT_ICON = 58;
+    private static final int INDEX_LINKS = 59;
+    private static final int EXTERNAL_TOC_DEPTH_MARKS = 60;
+    private static final int AVOID_HTML5 = 61;
 
     protected ComplexOption xheading = addComplexOption("heading-map");
     protected ComplexOption xpar = addComplexOption("paragraph-map");
@@ -209,6 +215,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
         		else { nValue = CSS1; }
         	}
         };
+        options[MAX_WIDTH] = new Option("max_width","800px");
         options[USE_DEFAULT_FONT] = new BooleanOption("use_default_font","false");
         options[DEFAULT_FONT_NAME] = new BooleanOption("default_font_name","");
         options[USE_DUBLIN_CORE] = new BooleanOption("use_dublin_core","true");
@@ -236,6 +243,9 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
         	@Override public void setString(String sValue) {
                 super.setString(sValue);
                 if ("auto".equals(sValue)) {
+                	nValue = -1;
+                }
+                else if ("0".equals(sValue)) {
                 	nValue = 0;
                 }
                 else {
@@ -244,6 +254,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
             }
         };
         options[INCLUDE_TOC] = new BooleanOption("include_toc","true");
+        options[INCLUDE_NCX] = new BooleanOption("include_ncx","true");
         options[SPLIT_LEVEL] = new IntegerOption("split_level","0") {
         	@Override public void setString(String sValue) {
                 super.setString(sValue);
@@ -274,6 +285,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
         options[IMAGE_SPLIT] = new Option("image_split","none");
         options[COVER_IMAGE] = new BooleanOption("cover_image","false");
         options[EMBED_SVG] = new BooleanOption("embed_svg","false");
+        options[EMBED_IMG] = new BooleanOption("embed_img","false");
         options[USE_MATHJAX] = new BooleanOption("use_mathjax","false");
         options[CALC_SPLIT] = new BooleanOption("calc_split","false");
         options[DISPLAY_HIDDEN_SHEETS] = new BooleanOption("display_hidden_sheets", "false");
@@ -286,6 +298,19 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
         options[UPLINK] = new Option("uplink","");
         options[DIRECTORY_ICON] = new Option("directory_icon","");
         options[DOCUMENT_ICON] = new Option("document_icon","");
+        options[INDEX_LINKS] = new BooleanOption("index_links","true");
+        options[EXTERNAL_TOC_DEPTH_MARKS] = new IntegerOption("external_toc_depth_marks","0")  {
+        	@Override public void setString(String sValue) {
+                super.setString(sValue);
+                if ("0".equals(sValue)) {
+                	nValue = 0;
+                }
+                else {
+                	nValue = Misc.getPosInteger(sValue,1);
+                }
+        	}
+        };
+        options[AVOID_HTML5] = new BooleanOption("avoid_html5","false");
     }
     
 	protected void readInner(Element elm) {
@@ -295,27 +320,38 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
             if (sFamily.length()==0) { // try old name
                 sFamily = elm.getAttribute("class");
             }
+            Map<String,String> attr = new HashMap<String,String>();
+
             String sElement = elm.getAttribute("element");
             String sCss = elm.getAttribute("css");
             if (sCss.length()==0) { sCss="(none)"; }
-            Map<String,String> attr = new HashMap<String,String>();
             attr.put("element", sElement);
             attr.put("css", sCss);
+
             String sBlockElement = elm.getAttribute("block-element");
             String sBlockCss = elm.getAttribute("block-css");
             if (sBlockCss.length()==0) { sBlockCss="(none)"; }
-
+            
+            String sBefore = elm.getAttribute("before");
+            String sAfter = elm.getAttribute("after");
+            
             if ("heading".equals(sFamily)) {
                 attr.put("block-element", sBlockElement);
                 attr.put("block-css", sBlockCss);
+                attr.put("before", sBefore);
+                attr.put("after", sAfter);
                 xheading.put(sName,attr);
             }
             if ("paragraph".equals(sFamily)) {
                 attr.put("block-element", sBlockElement);
                 attr.put("block-css", sBlockCss);
+                attr.put("before", sBefore);
+                attr.put("after", sAfter);
                 xpar.put(sName,attr);
             }
             else if ("text".equals(sFamily)) {
+                attr.put("before", sBefore);
+                attr.put("after", sAfter);
                 xtext.put(sName,attr);
             }
             else if ("frame".equals(sFamily)) {
@@ -351,6 +387,8 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
             smNode.setAttribute("css",attr.get("css"));
             if (attr.containsKey("block-element")) smNode.setAttribute("block-element",attr.get("block-element"));
             if (attr.containsKey("block-css")) smNode.setAttribute("block-css",attr.get("block-css"));
+            if (attr.containsKey("before")) smNode.setAttribute("before",attr.get("before"));
+            if (attr.containsKey("after")) smNode.setAttribute("after",attr.get("after"));
             dom.getDocumentElement().appendChild(smNode);
         }
     }
@@ -376,6 +414,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     public int xhtmlTableFormatting() { return ((XhtmlFormatOption) options[TABLE_FORMATTING]).getValue(); }
     public int tableSize() { return ((IntegerOption) options[TABLE_SIZE]).getValue(); }
     public int listFormatting() { return ((IntegerOption) options[LIST_FORMATTING]).getValue(); }
+    public String getMaxWidth() { return options[MAX_WIDTH].getString(); }
     public boolean useDefaultFont() { return ((BooleanOption) options[USE_DEFAULT_FONT]).getValue(); }
     public String defaultFontName() { return options[DEFAULT_FONT_NAME].getString(); }
     public boolean xhtmlUseDublinCore() { return ((BooleanOption) options[USE_DUBLIN_CORE]).getValue(); }
@@ -393,6 +432,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     public int formulas() { return ((IntegerOption) options[FORMULAS]).getValue(); }
     public int externalTocDepth() { return ((IntegerOption) options[EXTERNAL_TOC_DEPTH]).getValue(); }
     public boolean includeToc() { return ((BooleanOption) options[INCLUDE_TOC]).getValue(); }
+    public boolean includeNCX() { return ((BooleanOption) options[INCLUDE_NCX]).getValue(); }
     public int getXhtmlSplitLevel() { return ((IntegerOption) options[SPLIT_LEVEL]).getValue(); }
     public int getXhtmlRepeatLevels() { return ((IntegerOption) options[REPEAT_LEVELS]).getValue(); }
     public int pageBreakSplit() { return ((IntegerOption) options[PAGE_BREAK_SPLIT]).getValue(); }
@@ -400,6 +440,7 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     public String imageSplit() { return options[IMAGE_SPLIT].getString(); }
     public boolean coverImage() { return ((BooleanOption) options[COVER_IMAGE]).getValue(); }
     public boolean embedSVG() { return ((BooleanOption) options[EMBED_SVG]).getValue(); }
+    public boolean embedImg() { return ((BooleanOption) options[EMBED_IMG]).getValue(); }
     public boolean useMathJax() { return ((BooleanOption) options[USE_MATHJAX]).getValue(); }
     public boolean xhtmlCalcSplit() { return ((BooleanOption) options[CALC_SPLIT]).getValue(); }
     public boolean xhtmlDisplayHiddenSheets() { return ((BooleanOption) options[DISPLAY_HIDDEN_SHEETS]).getValue(); }
@@ -412,6 +453,9 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     public String getXhtmlUplink() { return options[UPLINK].getString(); }
     public String getXhtmlDirectoryIcon() { return options[DIRECTORY_ICON].getString(); }
     public String getXhtmlDocumentIcon() { return options[DOCUMENT_ICON].getString(); }
+    public boolean indexLinks() { return ((BooleanOption) options[INDEX_LINKS]).getValue(); }
+    public int externalTocDepthMarks() { return ((IntegerOption) options[EXTERNAL_TOC_DEPTH_MARKS]).getValue(); }
+    public boolean avoidHtml5() { return ((BooleanOption) options[AVOID_HTML5]).getValue(); }
 	
     public XhtmlStyleMap getXParStyleMap() { return getStyleMap(xpar); }
     public XhtmlStyleMap getXHeadingStyleMap() { return getStyleMap(xheading); }
@@ -428,7 +472,9 @@ public class XhtmlConfig extends writer2latex.base.ConfigBase {
     		String sCss = attr.containsKey("css") ? attr.get("css") : "";
     		String sBlockElement = attr.containsKey("block-element") ? attr.get("block-element") : "";
     		String sBlockCss = attr.containsKey("block-css") ? attr.get("block-css") : "";
-    		map.put(sName, sBlockElement, sBlockCss, sElement, sCss);
+    		String sBefore = attr.containsKey("before") ? attr.get("before") : "";
+    		String sAfter = attr.containsKey("after") ? attr.get("after") : "";
+    		map.put(sName, new XhtmlStyleMapItem(sBlockElement, sBlockCss, sElement, sCss, sBefore, sAfter));
     	}
     	return map;
 
