@@ -16,11 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  *  MA  02111-1307  USA
  *
- *  Copyright: 2002-2014 by Henrik Just
+ *  Copyright: 2002-2018 by Henrik Just
  *
  *  All Rights Reserved.
  * 
- *  Version 1.4 (2014-09-23)
+ *  Version 1.6 (2018-05-23)
  *
  */
 
@@ -40,7 +40,6 @@ import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.ParserConfigurationException;
 
-import writer2latex.api.MIMETypes;
 import writer2latex.base.DOMDocument;
 import writer2latex.office.XMLString;
 
@@ -69,8 +68,11 @@ public class XhtmlDocument extends DOMDocument {
     /** Constant to identify HTML5 documents */
     public static final int HTML5 = 3;
     
+    /** Constant to identify HTML5 documents with .xhtml extension */
+    public static final int XHTML5 = 4;
+    
     // Some static data
-    private static final String[] sExtension = { ".html", ".xhtml", ".xhtml", ".html" };
+    private static final String[] sExtension = { ".html", ".xhtml", ".xhtml", ".html", ".xhtml" };
 
     private static Set<String> blockPrettyPrint;
     private static Set<String> conditionalBlockPrettyPrint;
@@ -294,19 +296,19 @@ public class XhtmlDocument extends DOMDocument {
     }
     
     @Override public String getMIMEType() {
-    	switch (nType) {
-    	case XHTML10: return MIMETypes.XHTML;
-    	case XHTML11: return MIMETypes.XHTML_MATHML; // TODO: Change the constant names in MIMETypes, this is a bit confusing...
-    	case XHTML_MATHML: return MIMETypes.XHTML_MATHML;
-    	case HTML5: return MIMETypes.HTML5;
-    	}
-    	return "";
+    	// Get the real MIME type, not the pseudo ones used by the converter API
+    	// We always produce XHTML, thus
+    	return "application/xhtml+xml";
     }
     
     @Override public boolean isMasterDocument() {
     	return true;
     }
     
+    @Override public boolean containsMath() {
+    	return bodyNode!=null ? containsMath(bodyNode) : false;
+    }
+    
     public Element getHeadNode() { return headNode; }
 	
     public Element getBodyNode() { return bodyNode; }
@@ -324,7 +326,7 @@ public class XhtmlDocument extends DOMDocument {
     public Element getFooterNode() { return footerNode; }
 	
     public void createHeaderFooter() {
-    	if (nType==HTML5) {
+    	if (nType==HTML5 || nType==XHTML5) {
     		Element header1 = getContentDOM().createElement("header");
     		bodyNode.appendChild(header1);
             headerNode = getContentDOM().createElement("nav");
@@ -340,7 +342,7 @@ public class XhtmlDocument extends DOMDocument {
         contentNode.setAttribute("id",sContentId);
         bodyNode.appendChild(contentNode);
 
-    	if (nType==HTML5) {
+    	if (nType==HTML5 || nType==XHTML5) {
     		Element footer1 = getContentDOM().createElement("footer");
     		bodyNode.appendChild(footer1);
             footerNode = getContentDOM().createElement("nav");
@@ -447,6 +449,7 @@ public class XhtmlDocument extends DOMDocument {
                 /* An alternative is to use XHTML + MathML + SVG:
                 sPublicId = "-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN",
                 sSystemId = "http://www.w3.org/2002/04/xhtml-math-svg/xhtml-math-svg.dtd"); */
+           default: // Nothing
         }
         return new String[] { sPublicId, sSystemId };
     }
@@ -575,13 +578,13 @@ public class XhtmlDocument extends DOMDocument {
 
         // Omit XML prolog for pure XHTML 1.0 strict documents (HTML 4 compaitbility)
         // and for HTML5 documents (polyglot document)
-        if (nType!=XHTML10 && nType!=HTML5) {
+        if (nType!=XHTML10 && nType!=HTML5 && nType!=XHTML5) {
             osw.write("<?xml version=\"1.0\" encoding=\""+sEncoding+"\" ?>\n");
         }
         // Specify DOCTYPE (the user may require that no DOCTYPE is used;
         // this may be desirable for further transformations)
         if (!bNoDoctype) {
-        	if (nType==HTML5) {
+        	if (nType==HTML5 || nType==XHTML5) {
         		osw.write("<!DOCTYPE html>\n");
         	}
         	else {
@@ -632,7 +635,7 @@ public class XhtmlDocument extends DOMDocument {
     }
 
     private boolean isEmpty(String sTagName) {
-        return nType==HTML5 ? emptyHtml5Elements.contains(sTagName) : emptyElements.contains(sTagName);
+        return (nType==HTML5 || nType==XHTML5) ? emptyHtml5Elements.contains(sTagName) : emptyElements.contains(sTagName);
     }
 	
     // Write nodes; we only need element, text and comment nodes
@@ -680,7 +683,7 @@ public class XhtmlDocument extends DOMDocument {
                     osw.write("<"+node.getNodeName());
                     writeAttributes(node,osw);
                     // HTML compatibility: use end-tag even if empty
-                    if (nType<=XHTML11 || nType==HTML5) {
+                    if (nType<=XHTML11 || nType==HTML5 || nType==XHTML5) {
                         osw.write("></"+node.getNodeName()+">");
                     }
                     else {
@@ -964,6 +967,25 @@ public class XhtmlDocument extends DOMDocument {
 	    default: return null;
     	}
     }
+    
+    private boolean containsMath(Element node) {
+    	// First check the node itself
+    	if (node.getTagName().equals("math")) {
+    		return true;
+    	}
+    	// The check the children
+    	Node child = node.getFirstChild();
+    	while (child!=null) {
+    		if (child.getNodeType()==Node.ELEMENT_NODE) {
+    			if (containsMath((Element)child)) {
+    				return true;
+    			}
+    		}
+    		child = child.getNextSibling();
+    	}
+    	// And then look no further
+    	return false;
+    }
 
 
 }
